==> react-molecule-thumbnail-2.1.0.tgz: package/lib/index.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import AtomImage from '@s-ui/react-atom-image';
import cx from 'classnames';
var BASE_CLASS = 'sui-MoleculeThumbnail';
var CAPTION_CLASS = BASE_CLASS + "-caption";
var LINK_CLASS = BASE_CLASS + "-link";
var CONTAINER_IMAGE = BASE_CLASS + "-containerImage";
var SIZES = {
  LARGE: 'large',
  MEDIUM: 'medium',
  SMALL: 'small',
  XSMALL: 'xsmall'
};
var RATIOS = {
  '1:1': '1-1',
  '4:3': '4-3',
  '16:9': '16-9'
};
var SHAPES = {
  SQUARED: 'squared',
  CIRCLED: 'circled'
};

var MoleculeThumbnail = function MoleculeThumbnail(props) {
  var href = props.href,
      size = props.size,
      ratio = props.ratio,
      shape = props.shape,
      target = props.target,
      captionText = props.captionText,
      Link = props.linkFactory,
      propsImage = _objectWithoutProperties(props, ["href", "size", "ratio", "shape", "target", "captionText", "linkFactory"]);

  var ImageCaption = function ImageCaption() {
    return React.createElement("div", null, React.createElement("div", {
      className: cx("" + CONTAINER_IMAGE, CONTAINER_IMAGE + "--" + ratio)
    }, React.createElement(AtomImage, propsImage)), captionText && React.createElement("figcaption", {
      className: CAPTION_CLASS
    }, captionText));
  };

  return React.createElement("figure", {
    className: cx("" + BASE_CLASS, BASE_CLASS + "--" + size, BASE_CLASS + "--" + shape)
  }, href ? React.createElement(Link, {
    className: LINK_CLASS,
    href: href,
    target: target,
    rel: target === '_blank' && 'noopener'
  }, React.createElement(ImageCaption, null)) : React.createElement(ImageCaption, null));
};

MoleculeThumbnail.displayName = 'MoleculeThumbnail';
MoleculeThumbnail.defaultProps = {
  target: '_blank',
  size: SIZES.MEDIUM,
  shape: SHAPES.SQUARED,
  ratio: RATIOS['1:1'],
  // eslint-disable-next-line react/prop-types
  linkFactory: function linkFactory(_ref) {
    if (_ref === void 0) {
      _ref = {};
    }

    var _ref2 = _ref,
        children = _ref2.children,
        rest = _objectWithoutProperties(_ref2, ["children"]);

    return React.createElement("a", rest, children);
  }
};
export default MoleculeThumbnail;
export { SIZES as moleculeThumbnailSize, RATIOS as moleculeThumbnailRatio, SHAPES as moleculeThumbnailShape };

==> react-molecule-thumbnail-2.3.0.tgz: package/lib/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React from 'react';
import PropTypes from 'prop-types';
import AtomImage from '@s-ui/react-atom-image';
import cx from 'classnames';
var BASE_CLASS = 'sui-MoleculeThumbnail';
var CAPTION_CLASS = BASE_CLASS + "-caption";
var LINK_CLASS = BASE_CLASS + "-link";
var CONTAINER_IMAGE = BASE_CLASS + "-containerImage";
var SIZES = {
  LARGE: 'large',
  MEDIUM: 'medium',
  SMALL: 'small',
  XSMALL: 'xsmall'
};
var RATIOS = {
  '1:1': '1-1',
  '4:3': '4-3',
  '16:9': '16-9'
};
var SHAPES = {
  SQUARED: 'squared',
  CIRCLED: 'circled'
};

var MoleculeThumbnail = function MoleculeThumbnail(props) {
  var href = props.href,
      size = props.size,
      ratio = props.ratio,
      shape = props.shape,
      target = props.target,
      captionText = props.captionText,
      Link = props.linkFactory,
      propsImage = _objectWithoutPropertiesLoose(props, ["href", "size", "ratio", "shape", "target", "captionText", "linkFactory"]);

  var ImageCaption = function ImageCaption() {
    return React.createElement("div", null, React.createElement("div", {
      className: cx("" + CONTAINER_IMAGE, CONTAINER_IMAGE + "--" + ratio)
    }, React.createElement(AtomImage, propsImage)), captionText && React.createElement("figcaption", {
      className: CAPTION_CLASS
    }, captionText));
  };

  return React.createElement("figure", {
    className: cx("" + BASE_CLASS, BASE_CLASS + "--" + size, BASE_CLASS + "--" + shape)
  }, href ? React.createElement(Link, {
    className: LINK_CLASS,
    href: href,
    target: target,
    rel: target === '_blank' && 'noopener'
  }, React.createElement(ImageCaption, null)) : React.createElement(ImageCaption, null));
};

MoleculeThumbnail.displayName = 'MoleculeThumbnail';
MoleculeThumbnail.defaultProps = {
  target: '_blank',
  size: SIZES.MEDIUM,
  shape: SHAPES.SQUARED,
  ratio: RATIOS['1:1'],
  // eslint-disable-next-line react/prop-types
  linkFactory: function linkFactory(_ref) {
    if (_ref === void 0) {
      _ref = {};
    }

    var _ref2 = _ref,
        children = _ref2.children,
        rest = _objectWithoutPropertiesLoose(_ref2, ["children"]);

    return React.createElement("a", rest, children);
  }
};
export default MoleculeThumbnail;
export { SIZES as moleculeThumbnailSize, RATIOS as moleculeThumbnailRatio, SHAPES as moleculeThumbnailShape };
